@@ -1,6 +1,7 @@
-#include "fastcpd_class.h"
 #include "fastcpd_impl.h"
 
+#include "fastcpd.h"
+
 // Implementation of the fastcpd algorithm.
 //
 // @param data A data frame containing the data to be segmented.
@@ -10,7 +11,7 @@
 // @param segment_count Number of segments for initial guess.
 // @param trim Trimming for the boundary change points.
 // @param momentum_coef Momentum coefficient to be applied to each update.
-// @param k Function on number of epochs in SGD.
+// @param multiple_epochs_function Function on number of epochs in SGD.
 // @param family Family of the models. Can be "binomial", "poisson", "lasso",
 //   "lm" or "arma". If not provided, the user must specify the cost function
 //   and its gradient (and Hessian).
@@ -40,46 +41,30 @@
 // @param p_response Dimension of the response, used with multivariate
 //   response.
 // @param pruning_coef The constant to satisfy the pruning condition.
-// @param r_clock String indicating whether to profile the program using
-//   `RcppClock`. Empty string means no profiling.
 // @param r_progress Whether to show progress bar.
 //
 // @return A list containing the change points and the cost values for each
 //   segment.
 // [[Rcpp::export]]
-List fastcpd_impl(
-    mat data,
-    double beta,
-    const string cost_adjustment,
-    const unsigned int d,
-    const int segment_count,
-    const double trim,
-    const double momentum_coef,
-    Nullable<Function> k,
-    const string family,
-    const double epsilon,
-    const int p,
-    const colvec order,
-    Nullable<Function> cost,
-    Nullable<Function> cost_gradient,
-    Nullable<Function> cost_hessian,
-    const bool cp_only,
-    const double vanilla_percentage,
-    const bool warm_start,
-    colvec lower,
-    colvec upper,
-    colvec line_search,
-    const mat variance_estimate,
-    const unsigned int p_response,
-    const double pruning_coef,
-    const string r_clock,
-    const bool r_progress
-) {
+Rcpp::List fastcpd_impl(
+    const arma::mat& data, const double beta,
+    const std::string& cost_adjustment, const int segment_count,
+    const double trim, const double momentum_coef,
+    const Rcpp::Nullable<Rcpp::Function>& multiple_epochs_function,
+    const std::string& family, const double epsilon, const int p,
+    const arma::colvec& order, const Rcpp::Nullable<Rcpp::Function>& cost,
+    const Rcpp::Nullable<Rcpp::Function>& cost_gradient,
+    const Rcpp::Nullable<Rcpp::Function>& cost_hessian, const bool cp_only,
+    const double vanilla_percentage, const bool warm_start,
+    const arma::colvec& lower, const arma::colvec& upper,
+    const arma::colvec& line_search, const arma::mat& variance_estimate,
+    const unsigned int p_response, const double pruning_coef,
+    const bool r_progress) {
   fastcpd::classes::Fastcpd fastcpd_class(
-    beta, cost, cost_adjustment, cost_gradient, cost_hessian, cp_only, d, data,
-    epsilon, family, k, line_search, lower, momentum_coef, order,
-    p, p_response, pruning_coef, r_clock, r_progress, segment_count, trim,
-    upper, vanilla_percentage, variance_estimate, warm_start
-  );
-  return fastcpd_class.run();
+      beta, cost, cost_adjustment, cost_gradient, cost_hessian, cp_only, data,
+      epsilon, family, multiple_epochs_function, line_search, lower,
+      momentum_coef, order, p, p_response, pruning_coef, r_progress,
+      segment_count, trim, upper, vanilla_percentage, variance_estimate,
+      warm_start);
+  return fastcpd_class.Run();
 }
